==> qtjambi-qt3dcore-6.5.0-sources.jar: io/qt/qt3d/core/QCoreAspect.java <==
package io.qt.qt3d.core;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class Qt3DCore::QCoreAspect</p>
 */
public class QCoreAspect extends io.qt.qt3d.core.QAbstractAspect
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QCoreAspect.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QCoreAspect(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QCoreAspect() {
        this((io.qt.core.QObject)null);
    }
    
    public QCoreAspect(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QCoreAspect instance, io.qt.core.QObject parent);
    
    @QtUninvokable
    public final io.qt.qt3d.core.@Nullable QAspectJob calculateBoundingVolumeJob(){
        return calculateBoundingVolumeJob_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.core.QAspectJob calculateBoundingVolumeJob_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QCoreAspect(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QCoreAspect(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QCoreAspect instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3dcore-6.5.2-sources.jar: io/qt/qt3d/core/QCoreAspect.java <==
package io.qt.qt3d.core;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>Qt3DCore::QCoreAspect</code></p>
 */
public class QCoreAspect extends io.qt.qt3d.core.QAbstractAspect
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QCoreAspect.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QCoreAspect(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QCoreAspect() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <code>Qt3DCore::QCoreAspect::<wbr>QCoreAspect(QObject*)</code></p>
     */
    public QCoreAspect(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QCoreAspect instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code>Qt3DCore::QCoreAspect::<wbr>calculateBoundingVolumeJob()const</code></p>
     */
    @QtUninvokable
    public final io.qt.qt3d.core.@Nullable QAspectJob calculateBoundingVolumeJob(){
        return calculateBoundingVolumeJob_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.core.QAspectJob calculateBoundingVolumeJob_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QCoreAspect(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QCoreAspect(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QCoreAspect instance, QDeclarativeConstructor constructor);
    
}
